@@ -9,16 +9,15 @@ setGeneric("lm")
 setGeneric("coef")
 setGeneric("subset")
 
+setOldClass("edsurvey.data.frame")
+setOldClass("light.edsurvey.data.frame")
+setOldClass("edsurvey.data.frame.list")
+
+setAs("light.edsurvey.data.frame", "data.frame", function(from) {
+  as.data.frame.light.edsurvey.data.frame(from)
+})
+
 setOldClass("edsurveyLm")
 setOldClass("edsurveyLmList")
 setOldClass("edsurveyGlm")
 setOldClass("edsurveyGlmList")
-
-setOldClass("edsurvey.data.frame")
-setOldClass("light.edsurvey.data.frame")
-setOldClass("edsurvey.data.frame.list")
-setClassUnion("sdf", members = c("edsurvey.data.frame","edsurvey.data.frame.list","light.edsurvey.data.frame"))
-## as(some.light.edsurvey.data.frame)
-setAs("light.edsurvey.data.frame","data.frame", function(from) {
-  as.data.frame.light.edsurvey.data.frame(from)
-})
