@@ -2,27 +2,27 @@
 #'
 #' @description Provides instructions to download CivED or ICCS data to be processed in \code{readCivEDICCS}.   
 #' 
-#' @param years an integer vector indicating the study year. Valid years are 1999 and 2009.
+#' @param years an integer vector indicating the study year. Valid years are 1999, 2009, and 2016.
 #' @author Tom Fink
 #' 
 #' @example man/examples/downloadICCS.R
 #' @seealso \code{\link{readCivEDICCS}}
 #' @importFrom utils browseURL
 #' @export
-downloadCivEDICCS <- function(years=c(1999, 2009)) {
+downloadCivEDICCS <- function(years=c(1999, 2009, 2016)) {
   
   if(is.null(years)){
     stop(paste0("The argument ", sQuote("years"), " must not be null."))
   }
   
-  if(any(!(years %in% c(1999, 2009)))){
-    stop(paste0("The argument ", sQuote("years"), " must have values of only ", sQuote("1999"), " or ", sQuote("2009"), "."))
+  if(any(!(years %in% c(1999, 2009, 2016)))){
+    stop(paste0("The argument ", sQuote("years"), " must have values of only ", sQuote("1999"), ", ",  sQuote("2009"), ", or ", sQuote("2016"), "."))
   }
   
   linkURL <- "https://www.iea.nl/data-tools/repository"
   
   txt <- c()
-  txt <- c(txt, paste0("Please manually download and extract the SPSS (*.sav) formatted CivED 1999 or ICCS 2009 study data files from the IEA Data Repository to a folder on your local system or network. ",
+  txt <- c(txt, paste0("Please manually download and extract the SPSS (*.sav) formatted CivED 1999, ICCS 2009, or ICCS 2016 study data files from the IEA Data Repository to a folder on your local system or network. ",
                        "After the following steps are completed, the ", dQuote("readCivEDICCS"), " function can be used to read in the data. ",
                        "See help page (?readCivEDICCS) for more details."))
   txt <- c(txt, "\n")
@@ -35,7 +35,7 @@ downloadCivEDICCS <- function(years=c(1999, 2009)) {
                        "Follow your web browser's prompts to download the resulting *.zip file to a folder location you can find later."))
   
   txt <- c(txt, paste0("\t", "4) Locate your downloaded zip file (*.zip) container and use an extraction program to extract the folder's file contents. ",
-                       "It is recommended to extract the SPSS (*.sav) files to an easy-to-remember folder path based on the study and year (e.g., for Microsoft Windows OS, ", sQuote("C:/EdSurveyData/CivED/1999/"), ", ", sQuote("C:/EdSurveyData/ICCS/2009/"), ")."))
+                       "It is recommended to extract the SPSS (*.sav) files to an easy-to-remember folder path based on the study and year (e.g., for Microsoft Windows OS, ", pasteItems(sQuote(c("C:/EdSurveyData/CivED/1999/", "C:/EdSurveyData/ICCS/2009/"), "C:/EdSurveyData/ICCS/2016/")), ")."))
   
   txt <- c(txt, "\n")
 
