@@ -58,17 +58,16 @@ downloadPIAAC <- function(root, cycle=1, cache=FALSE, verbose=TRUE) {
   }
   
   url0 <- "https://webfs.oecd.org"
-  codebook <- 'http://www.oecd.org/site/piaac/International%20Codebook_PIAAC%20Public-use%20File%20(PUF)%20Variables%20and%20Values.xlsx' 
+  codebook <- 'https://www.oecd.org/skills/piaac/International%20Codebook_PIAAC%20Public-use%20File%20(PUF)%20Variables%20and%20Values.xlsx' 
   for (f in data_files) {
     fn <- basename(f)
     if(!file.exists(file.path(yroot,fn))) {
       # us12_14 download is a zip file and needs special processing
       if(f == "/skills/piaac/data/CSV_prgusap1.zip"){
-        download.file(paste0("https://www.oecd.org/", f), file.path(yroot, fn), mode = "wb", method = "auto") # auto helps with OS detection
+        download.file(paste0("https://www.oecd.org/", f), file.path(yroot, fn), mode = "wb", method = "auto")
         unzip(file.path(yroot, fn), "prgusap1.csv", exdir = file.path(yroot))
       } else {
-        # regular download case
-        download.file(paste0(url0, f), file.path(yroot, fn), mode = "wb", method = "auto")
+        download.file(paste0(url0, f), file.path(yroot, fn), mode = "w", method = "auto")
       }
     } else {
       if (verbose) {
@@ -78,26 +77,22 @@ downloadPIAAC <- function(root, cycle=1, cache=FALSE, verbose=TRUE) {
   }
   fn <- "international-codebook.xlsx"
   if(!file.exists(file.path(yroot,fn))) {
-    # download codebook if doesn't exist 
-    download.file(codebook,file.path(yroot,fn), mode = "wb", method = "auto")
+    download.file(codebook,file.path(yroot,fn), mode = "wb")
   } else {
     if (verbose) {
       cat(paste0("Found downloaded cycle ",cycle," PIAAC codebook file ",fn, ".\n"))
     }
   }
-  # read_excel causes blank white space to print, even when functioning properly.
-  # we add an invisible() here to prevent the print and pass test-5, which expects the download function 
-  # to be silent. Even with the invisible(), the tryCatch will still catch a corrupted file. 
-  invisible(capture.output(test <- read_excel(file.path(yroot,fn), sheet = 1)))
-  tryCatch(test,
-           error = function(cond) {
-             cache <<- FALSE
-             cat(paste0("The downloaded codebook file is corrupt. You need to manually download the codebook at the given link: ",sQuote(codebook)," to the folder ", sQuote(yroot),".\n"))
-             nav <- readline(prompt = "Please enter 'Y' if you wish to launch this URL in your browser: ")
-             if (tolower(trimws(nav)) == "y") {
-               browseURL(codebook)
-             }
-           })
+  
+  test <- tryCatch(read_excel(file.path(yroot,fn), sheet = 1),
+                   error = function(cond) {
+                     cache <<- FALSE
+                     cat(paste0("The downloaded codebook file is corrupt. You need to manually download the codebook at the given link: ",sQuote(codebook)," to the folder ", sQuote(yroot),".\n"))
+                     nav <- readline(prompt = "Please enter 'Y' if you wish to launch this URL in your browser: ")
+                     if (tolower(trimws(nav)) == "y") {
+                       browseURL(codebook)
+                     }
+                   })
   if (cache) {
     notUsed <- readPIAAC(yroot, countries = "*", verbose = verbose)
     notUsed <- NULL
