@@ -1,5 +1,5 @@
 \dontrun{
-usa <- read_ePIRLS("C:/ePIRLS/2016", countries = c("usa"))
+usa <- read_ePIRLS("~/ePIRLS/2016", countries = c("usa"))
 gg <- getData(usa, c("itsex", "totwgt", "erea"))
 head(gg)
 edsurveyTable(erea ~ itsex, usa)
