@@ -1,3 +1,4 @@
+\dontrun{
 # read in the example data (generated, not real student data)
 sdf <- readNAEP(system.file("extdata/data", "M36NT2PM.dat", package = "NAEPprimer"))
 
@@ -18,3 +19,4 @@ unname(coef(lm1)["dsexFemale"] - coef(lm1)["b017451Every day"])
 sqrt(lm1$coefmat["dsexFemale", "se"]^2
      + lm1$coefmat["b017451Every day", "se"]^2
      - 2 * covFEveryDay)
+}
