@@ -123,9 +123,10 @@ printREF <- c("an edsurvey.data.frame.list with 4 elements",
               "Default Conditions:",
               "tolower(rptsamp) == \"reporting sample\"",
               "Achievement Levels:",
-              "Basic: 262",
-              "Proficient: 299",
-              "Advanced: 333",
+              "Mathematics:",
+              "Basic: 262.00",
+              "Proficient: 299.00",
+              "Advanced: 333.00",
               "",
               "",
               "Element 2",
@@ -158,9 +159,10 @@ printREF <- c("an edsurvey.data.frame.list with 4 elements",
               "Default Conditions:",
               "tolower(rptsamp) == \"reporting sample\"",
               "Achievement Levels:",
-              "Basic: 262",
-              "Proficient: 299",
-              "Advanced: 333",
+              "Mathematics:",
+              "Basic: 262.00",
+              "Proficient: 299.00",
+              "Advanced: 333.00",
               "",
               "",
               "Element 3",
@@ -193,9 +195,10 @@ printREF <- c("an edsurvey.data.frame.list with 4 elements",
               "Default Conditions:",
               "tolower(rptsamp) == \"reporting sample\"",
               "Achievement Levels:",
-              "Basic: 262",
-              "Proficient: 299",
-              "Advanced: 333",
+              "Mathematics:",
+              "Basic: 262.00",
+              "Proficient: 299.00",
+              "Advanced: 333.00",
               "",
               "",
               "Element 4",
@@ -228,7 +231,8 @@ printREF <- c("an edsurvey.data.frame.list with 4 elements",
               "Default Conditions:",
               "tolower(rptsamp) == \"reporting sample\"",
               "Achievement Levels:",
-              "Basic: 262",
-              "Proficient: 299",
-              "Advanced: 333"
-              )
\ No newline at end of file
+              "Mathematics:",
+              "Basic: 262.00",
+              "Proficient: 299.00",
+              "Advanced: 333.00"
+              )
