@@ -17,7 +17,7 @@ g3dREF <- c("Call: gap(variable = \"mmat\", data = fin4.11, groupA = asbg01 == \
 
 g2pREF <- c("gapList",
             "Call: gap(variable = \"mmat\", data = fin4.11, groupA = asbg01 == \"BOY\", ", 
-            "    groupB = asbg01 == \"GIRL\", percentiles = c(50, 90))", 
+            "    groupB = asbg01 == \"GIRL\", percentiles = c(50, 90), pctMethod = \"symmetric\")", 
             "",
             "Labels:",
             " group       definition",
@@ -30,8 +30,8 @@ g2pREF <- c("gapList",
             "",
             "Results:",
             " percentiles estimateA estimateAse estimateB estimateBse    diffAB     covAB diffABse diffABpValue     dofAB", 
-            "          50  554.1330    2.372200  544.5890    3.398268  9.543939 0.2109867 4.093114   0.02076780 189.38167", 
-            "          90  637.3013    4.885717  624.3285    4.860274 12.972846 0.1195478 6.874110   0.06226954  92.47503")
+            "          50  554.1330    2.372135  544.5890    3.398268  9.543939 0.2097460 4.093380   0.02077607 189.35935",
+            "          90  637.2713    4.882122  624.3219    4.865290 12.949391 0.2570735 6.855072   0.06199803  93.19778")
 
 g1alREF <- c("Call: gap(variable = \"mmat\", data = fin4.11, groupA = asbg01 == \"BOY\", ", 
              "    groupB = asbg01 == \"GIRL\", achievementLevel = \"Low International Benchmark\", ", 
@@ -99,17 +99,18 @@ swREF <-  c("There are 4 full sample weights in this edsurvey.data.frame:",
 
 pctREF <- c("Percentile",
             "Call: percentile(variable = \"mmat\", percentiles = c(0, 1, 25, 50, 75, ", 
-            "    99, 100), data = usa4.07)",
-            "full data n: 12883",
-            "n used: 7896", "",
-            " percentile estimate      se      df confInt.ci_lower confInt.ci_upper nsmall",
-            "          0   248.67 14.4169  0.0000           248.67           248.67    0.0", 
-            "          1   345.74  6.0948  6.5838           328.63           357.17   81.8", 
-            "         25   479.13  2.3386 25.2124           473.46           484.68 1995.0", 
-            "         50   530.75  2.5736 24.6062           525.49           535.98 3926.0", 
-            "         75   581.48  2.9514 28.7230           576.04           586.74 1958.6", 
-            "         99   692.29  4.0554  4.1100           686.24           702.97   77.4", 
-            "        100   781.63 18.7631  0.0000           781.63           781.63    0.0")
+            "    99, 100), data = usa4.07, pctMethod = \"unbiased\")",
+            "full data n: 12883", 
+            "n used: 7896",
+            "",
+            " percentile estimate      se     df confInt.ci_lower confInt.ci_upper", 
+            "          0   248.67 14.4169  0.000           248.67           248.67", 
+            "          1   345.74  6.0948 19.316           328.63           357.17", 
+            "         25   479.13  2.3386 73.969           473.46           484.68", 
+            "         50   530.75  2.5736 72.190           525.49           535.98", 
+            "         75   581.48  2.9514 84.268           576.04           586.74", 
+            "         99   692.29  4.0554 12.058           686.24           702.97", 
+            "        100   781.63 18.7631  0.000           781.63           781.63")
 
 logit1REF <- c("",
                "Formula: readSciOften ~ itsex + at4gsex",
@@ -147,56 +148,75 @@ probit1REF <- c("",
                 "---",
                 "Signif. codes:  0 '***' 0.001 '**' 0.01 '*' 0.05 '.' 0.1 ' ' 1")
 
-#for whatever reason, the sQuote behaves really odd.  change the ‘srea’ to 'srea'.  all.equal will show false, but expect_equal must coerce it somehow?
-spv <-  c("There are 14 subject scale(s) or subscale(s) in this edsurvey.data.frame:",                       
-          "'mmat' subject scale or subscale with 5 plausible values (the default).",                         
-          "  The plausible value variables are: 'asmmat01', 'asmmat02', 'asmmat03', 'asmmat04', and 'asmmat05'",
-          "",                                         
-          "'ssci' subject scale or subscale with 5 plausible values.",
-          "  The plausible value variables are: 'asssci01', 'asssci02', 'asssci03', 'asssci04', and 'asssci05'",
-          "",                                         
-          "'mdat' subject scale or subscale with 5 plausible values.",
-          "  The plausible value variables are: 'asmdat01', 'asmdat02', 'asmdat03', 'asmdat04', and 'asmdat05'",
-          "",                                         
-          "'mgeo' subject scale or subscale with 5 plausible values.",
-          "  The plausible value variables are: 'asmgeo01', 'asmgeo02', 'asmgeo03', 'asmgeo04', and 'asmgeo05'",
-          "",                                         
-          "'mnum' subject scale or subscale with 5 plausible values.",
-          "  The plausible value variables are: 'asmnum01', 'asmnum02', 'asmnum03', 'asmnum04', and 'asmnum05'",
-          "",                                         
-          "'sear' subject scale or subscale with 5 plausible values.",
-          "  The plausible value variables are: 'assear01', 'assear02', 'assear03', 'assear04', and 'assear05'",
-          "",                                         
-          "'slif' subject scale or subscale with 5 plausible values.",
-          "  The plausible value variables are: 'asslif01', 'asslif02', 'asslif03', 'asslif04', and 'asslif05'",
-          "",                                         
-          "'sphy' subject scale or subscale with 5 plausible values.",
-          "  The plausible value variables are: 'assphy01', 'assphy02', 'assphy03', 'assphy04', and 'assphy05'",
-          "",                                         
-          "'mkno' subject scale or subscale with 5 plausible values.",
-          "  The plausible value variables are: 'asmkno01', 'asmkno02', 'asmkno03', 'asmkno04', and 'asmkno05'",
-          "",                                         
-          "'mapp' subject scale or subscale with 5 plausible values.",
-          "  The plausible value variables are: 'asmapp01', 'asmapp02', 'asmapp03', 'asmapp04', and 'asmapp05'",
-          "",                                         
-          "'mrea' subject scale or subscale with 5 plausible values.",
-          "  The plausible value variables are: 'asmrea01', 'asmrea02', 'asmrea03', 'asmrea04', and 'asmrea05'",
-          "",                                         
-          "'skno' subject scale or subscale with 5 plausible values.",
-          "  The plausible value variables are: 'asskno01', 'asskno02', 'asskno03', 'asskno04', and 'asskno05'",
-          "",                                         
-          "'sapp' subject scale or subscale with 5 plausible values.",
-          "  The plausible value variables are: 'assapp01', 'assapp02', 'assapp03', 'assapp04', and 'assapp05'",
-          "",                                         
-          "'srea' subject scale or subscale with 5 plausible values.",
+spv <-  c("There are 14 subject scale(s) or subscale(s) in this edsurvey.data.frame:", 
+          "'mmat' subject scale or subscale with 5 plausible values (the default).", 
+          "  The plausible value variables are: 'asmmat01', 'asmmat02', 'asmmat03', 'asmmat04', and 'asmmat05'", 
+          "",
+          "'ssci' subject scale or subscale with 5 plausible values.", 
+          "  The plausible value variables are: 'asssci01', 'asssci02', 'asssci03', 'asssci04', and 'asssci05'", 
+          "",
+          "'mdat' subject scale or subscale with 5 plausible values.", 
+          "  The plausible value variables are: 'asmdat01', 'asmdat02', 'asmdat03', 'asmdat04', and 'asmdat05'", 
+          "",
+          "'mgeo' subject scale or subscale with 5 plausible values.", 
+          "  The plausible value variables are: 'asmgeo01', 'asmgeo02', 'asmgeo03', 'asmgeo04', and 'asmgeo05'", 
+          "",
+          "'mnum' subject scale or subscale with 5 plausible values.", 
+          "  The plausible value variables are: 'asmnum01', 'asmnum02', 'asmnum03', 'asmnum04', and 'asmnum05'", 
+          "",
+          "'sear' subject scale or subscale with 5 plausible values.", 
+          "  The plausible value variables are: 'assear01', 'assear02', 'assear03', 'assear04', and 'assear05'", 
+          "",
+          "'slif' subject scale or subscale with 5 plausible values.", 
+          "  The plausible value variables are: 'asslif01', 'asslif02', 'asslif03', 'asslif04', and 'asslif05'", 
+          "",
+          "'sphy' subject scale or subscale with 5 plausible values.", 
+          "  The plausible value variables are: 'assphy01', 'assphy02', 'assphy03', 'assphy04', and 'assphy05'", 
+          "",
+          "'mkno' subject scale or subscale with 5 plausible values.", 
+          "  The plausible value variables are: 'asmkno01', 'asmkno02', 'asmkno03', 'asmkno04', and 'asmkno05'", 
+          "",
+          "'mapp' subject scale or subscale with 5 plausible values.", 
+          "  The plausible value variables are: 'asmapp01', 'asmapp02', 'asmapp03', 'asmapp04', and 'asmapp05'", 
+          "",
+          "'mrea' subject scale or subscale with 5 plausible values.", 
+          "  The plausible value variables are: 'asmrea01', 'asmrea02', 'asmrea03', 'asmrea04', and 'asmrea05'", 
+          "",
+          "'skno' subject scale or subscale with 5 plausible values.", 
+          "  The plausible value variables are: 'asskno01', 'asskno02', 'asskno03', 'asskno04', and 'asskno05'", 
+          "",
+          "'sapp' subject scale or subscale with 5 plausible values.", 
+          "  The plausible value variables are: 'assapp01', 'assapp02', 'assapp03', 'assapp04', and 'assapp05'", 
+          "",
+          "'srea' subject scale or subscale with 5 plausible values.", 
           "  The plausible value variables are: 'assrea01', 'assrea02', 'assrea03', 'assrea04', and 'assrea05'",
           "")
 
-
 assignTest1 <- c("    asmrea01        asmrea02        asmrea03        asmrea04        asmrea05    ", 
                  " Min.   :  5.0   Min.   :  5.0   Min.   :  5.0   Min.   :  5.0   Min.   :  5.0  ",
                  " 1st Qu.:246.5   1st Qu.:246.8   1st Qu.:249.8   1st Qu.:248.5   1st Qu.:247.3  ",
                  " Median :327.7   Median :326.9   Median :328.6   Median :328.6   Median :329.4  ",
                  " Mean   :328.0   Mean   :328.4   Mean   :329.9   Mean   :329.1   Mean   :328.8  ",
                  " 3rd Qu.:410.8   3rd Qu.:412.3   3rd Qu.:412.5   3rd Qu.:410.5   3rd Qu.:413.4  ",
-                 " Max.   :784.2   Max.   :732.8   Max.   :729.6   Max.   :746.9   Max.   :707.6  ")
\ No newline at end of file
+                 " Max.   :784.2   Max.   :732.8   Max.   :729.6   Max.   :746.9   Max.   :707.6  ")
+
+mmlIntREF <- c("  (Intercept) Population SD ", 
+               "       539.82         81.72 ")   
+mmlSumREF <- c("Call:", "mml.sdf(formula = mmat ~ 1, data = mmlSDF, weightVar = \"totwgt\", ",
+               "    verbose = TRUE)", 
+               "Summary Call:", 
+               "summary.edSurveyMML(object = mmlTIMSS)", 
+               "", 
+               "Summary:",
+               "            Estimate   StdErr t.value", 
+               "(Intercept) 539.8184   0.0458   11774",
+               "", 
+               "Residual Variance Estimate:", 
+               "              Estimate StdErr", 
+               "Population SD    81.72 0.0391",
+               "",
+               "Convergence = Normal exit from bobyqa", 
+               "Iterations = 27", 
+               "LogLike = -52453394.92", 
+               "Observations = 10017", 
+               "Weighted observations = 3752699.01" )
